@@ -68,6 +68,7 @@ class CompilerRunner(object):
     """
 
     compiler_dict = None  # Subclass to vendor/binary dict
+    environ_key_ldflags = 'LDFLAGS'
 
     # Standards should be a tuple of supported standards
     # (first one will be the default)
@@ -83,7 +84,7 @@ class CompilerRunner(object):
 
     logger = None
 
-    default_compile_options = ('pic', 'warn', 'fast')
+    default_compile_options = ('pic', 'warn')  # , 'fast'
 
     # http://software.intel.com/en-us/articles/intel-mkl-link-line-advisor
     # MKL 11.1 x86-64, *nix, MKLROOT env. set, dynamic linking
@@ -128,7 +129,7 @@ class CompilerRunner(object):
                  library_dirs=None, std=None, options=None, define=None,
                  undef=None, strict_aliasing=None, logger=None,
                  preferred_vendor=None, metadir=None, lib_options=None,
-                 only_update=False, **kwargs):
+                 only_update=False, ldflags=None, **kwargs):
 
         cwd = cwd or '.'
         metadir = get_abspath(metadir or '.', cwd=cwd)
@@ -195,7 +196,8 @@ class CompilerRunner(object):
             self.flags.append(self.std_formater[
                 self.compiler_name](self.std))
 
-        self.linkline = []
+        self.linkline = (ldflags or []) + [lf for lf in map(
+            str.strip, os.environ.get(self.environ_key_ldflags, "").split()) if lf != ""]
 
         # Handle options
         for opt in self.options:
